# TetherHelix-Protocol-gRPC-Python

This package for python is for supporting bot, backend, bff, front layer's communications,
specifing gRPC protocol for them.

## 🔗 Links
[Main Repo](https://github.com/TetherHelix/TetherHelix-Protocol-gRPC)